@@ -3,6 +3,8 @@ import importlib
 
 from celery.loaders.base import BaseLoader
 
+from django.core.mail import mail_admins
+
 _RACE_PROTECTION = False
 
 
@@ -21,13 +23,13 @@ class DjangoLoader(BaseLoader):
         return settings
 
     def close_database(self):
-        from django.db import connection
+        import django.db
         db_reuse_max = getattr(self.conf, "CELERY_DB_REUSE_MAX", None)
         if not db_reuse_max:
-            return connection.close()
+            return django.db.close_connection()
         if self._db_reuse >= db_reuse_max * 2:
             self._db_reuse = 0
-            return connection.close()
+            return django.db.close_connection()
         self._db_reuse += 1
 
     def close_cache(self):
@@ -62,6 +64,9 @@ class DjangoLoader(BaseLoader):
         self.import_default_modules()
         autodiscover()
 
+    def mail_admins(self, subject, body, fail_silently=False):
+        return mail_admins(subject, body, fail_silently=fail_silently)
+
 
 def autodiscover():
     """Include tasks for all applications in ``INSTALLED_APPS``."""
