@@ -3,14 +3,14 @@
 Curses Celery Event Viewer.
 
 """
-from django.core.management.base import BaseCommand
-
 from celery.bin.celeryev import run_celeryev, OPTION_LIST
 
+from djcelery.management.base import CeleryCommand
 
-class Command(BaseCommand):
+
+class Command(CeleryCommand):
     """Run the celery curses event viewer."""
-    option_list = BaseCommand.option_list + OPTION_LIST
+    option_list = CeleryCommand.option_list + OPTION_LIST
     help = 'curses celery event viewer'
 
     def handle(self, *args, **options):
