@@ -1,10 +1,9 @@
-import unittest2 as unittest
-
 from django.conf import settings
 
 from celery.task import tasks
 
 from djcelery.loaders import autodiscover
+from djcelery.tests.utils import unittest
 
 
 class TestDiscovery(unittest.TestCase):
