@@ -8,13 +8,14 @@ from celery.result import AsyncResult
 from celery.registry import tasks
 from celery.backends import default_backend
 
-# Ensure builtin tasks are loaded for task_list view
+# Ensure built-in tasks are loaded for task_list view
 import celery.task.builtins
 
 
 def task_view(task):
     """Decorator turning any task into a view that applies the task
-    asynchronously.
+    asynchronously. Keyword arguments (via URLconf, etc.) will
+    supercede GET or POST parameters when there are conflicts.
 
     Returns a JSON dictionary containing the keys ``ok``, and
         ``task_id``.
@@ -26,6 +27,7 @@ def task_view(task):
             request.POST.copy() or request.GET.copy()
         kwargs = dict((key.encode("utf-8"), value)
                     for key, value in kwargs.items())
+        kwargs.update(options)
 
         result = task.apply_async(kwargs=kwargs)
         response_data = {"ok": "true", "task_id": result.task_id}
@@ -63,7 +65,7 @@ def task_status(request, task_id):
     response_data = dict(id=task_id, status=status, result=res)
     if status in default_backend.EXCEPTION_STATES:
         traceback = default_backend.get_traceback(task_id)
-        response_data.update({"result": str(res.args[0]),
+        response_data.update({"result": repr(res),
                               "exc": get_full_cls_name(res.__class__),
                               "traceback": traceback})
 
